@@ -303,7 +303,7 @@ var os2 = process.platform, arch = os2 === "darwin" && process.arch === "x64" &&
   },
   {
     os: "linux",
-    arch: "aarch64",
+    arch: "arm64",
     abi: "musl",
     bin: "bun-linux-aarch64-musl",
     exe: "bin/bun"
@@ -439,7 +439,7 @@ function installBun(platform, dst) {
     write(join(cwd, "package.json"), "{}");
     let { exitCode } = spawn(
       "npm",
-      ["install", "--loglevel=error", "--prefer-offline", "--no-audit", "--progress=false", `${module2}@1.2.18`],
+      ["install", "--loglevel=error", "--prefer-offline", "--no-audit", "--progress=false", `${module2}@1.3.0`],
       {
         cwd,
         stdio: "pipe",
@@ -460,7 +460,7 @@ function installBun(platform, dst) {
 __name(installBun, "installBun");
 function downloadBun(platform, dst) {
   return __async(this, null, function* () {
-    let tgz = yield (yield fetch(`https://registry.npmjs.org/@oven/${platform.bin}/-/${platform.bin}-1.2.18.tgz`)).arrayBuffer(), buffer;
+    let tgz = yield (yield fetch(`https://registry.npmjs.org/@oven/${platform.bin}/-/${platform.bin}-1.3.0.tgz`)).arrayBuffer(), buffer;
     try {
       buffer = (0, import_zlib.unzipSync)(tgz);
     } catch (cause) {
@@ -487,7 +487,7 @@ function downloadBun(platform, dst) {
 }
 __name(downloadBun, "downloadBun");
 function optimizeBun(path2) {
-  let installScript = os2 === "win32" ? 'powershell -c "irm bun.sh/install.ps1 | iex"' : "curl -fsSL https://bun.sh/install | bash";
+  let installScript = os2 === "win32" ? 'powershell -c "irm bun.com/install.ps1 | iex"' : "curl -fsSL https://bun.com/install | bash";
   try {
     rename(path2, join(__dirname, "bin", "bun.exe")), link(join(__dirname, "bin", "bun.exe"), join(__dirname, "bin", "bunx.exe"));
     return;
